local L = PetSelector.L
local GetStablePetInfo = GetStablePetInfo

-- Returns the currently suggested pet
-- Icon, Name, Level, Family, Type (Ferocity, Cunning, Tenacity), Stable Slot, Is it exotic?

function PetSelector:GetSelectedPet()

	local pet = self.selectedpet
	
	if pet then
	
		return pet.icon, pet.name, pet.level, pet.family, pet.class, pet.slot, pet.exotic
		
	else
	
		return nil

	end
			
end

-- Attempts to create/edit a macro so summon the selected pet

function PetSelector:SetPetMacro()

	local pet = self.selectedpet
	local mid, body, nid
	
	if not pet then return end

	body = "" --"#show Call Pet\n"
	
	--pet is in the stable
	if pet.slot > 5 then 
	
		StaticPopupDialogs["PETSELECTOR_STABLED"].text = string.format(L["%s is stabled"], pet.name)
		body = body .. "/run StaticPopup_Show(\"PETSELECTOR_STABLED\")"
		
	elseif pet.slot == 0 then
		
		--pet is already active
		body = body .. "/cast [@pet, dead] Revive Pet\n/cast [nopet] Call Pet " .. pet.slot
	
	else
	
		body = body .. "/cast [pet] Dismiss Pet\n/cast [nopet] Call Pet " .. pet.slot
	
	end

	--does the macro already exist?
	mid = GetMacroIndexByName(L["Pet Selector"])
	
	if mid == 0 then

		--no extant macro, so create one
		mid = CreateMacro(L["Pet Selector"], 109, body)
		
	else

		--edit an existing macro
		nid = EditMacro(mid, nil, nil, body)
		
	end
	
end

--[[
	Returns a table of (all) the hunter's pets within 5 levels of the player's current level
	AllPets = include stabled pets (any non-nil value)
	returns:
 [1] = {
	icon = In game pet icon,
	name = The pet's name,
	level = The pet's level,
	family = The pet's family (localised),
	class = Tenacity | Ferocity | Cunning (localised),
	slot = Stable slot (anything over 5 is with the stable master)
	exotic = Is this an exotic pet?
 }
 --]]

function PetSelector:GetPets(AllPets)

	local pets = {}
	local icon, name, level, family, class, slot
	
	for slot = 1, 25 do
	
		icon, name, level, family, class = GetStablePetInfo(slot)
		
		if name then
		
			if self.debug then
			
				--print(slot .. ": " .. name .. " l: " .. level)
				
			end
			
			if (self.PlayerLevel - level < 4) then
			
				if ((slot > 5) and (self.db.profile.stabled or AllPets)) or (slot < 6) then
				
					table.insert(pets, {
						icon = icon, name = name, level = level, family = family, class = class, slot = slot, exotic = self:IsExotic(family)
					})
					
				end
				
			end
			
		end
		
	end
	
	return pets
	
end

-- Returns true if petfamily is an exotic pet family
-- returns nil otherwise
-- petfamily is the localised pet family name

function PetSelector:IsExotic(petfamily)

	local exotic, family
	
	for _, family in ipairs(self.ExoticPets) do
	
		if petfamily == family then
		
			exotic = true
			break
			
		end
		
	end
	
	return exotic

end